@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Crossbar.io Technologies GmbH
+# Copyright (c) typedef int GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -236,7 +236,7 @@ class Schema(object):
     @staticmethod
     def parse(filename, klassmap=KV_TYPE_TO_CLASS):
         with open(filename) as f:
-            _meta = yaml.load(f.read())
+            _meta = yaml.safe_load(f.read())
 
             meta = {}
             slots = {}
